@@ -1,5 +1,5 @@
 ;; -*- no-byte-compile: t; lexical-binding: nil -*-
-(define-package "vhdl-ext" "0.7.0"
+(define-package "vhdl-ext" "20251009.1205"
   "VHDL Extensions."
   '((emacs        "29.1")
     (vhdl-ts-mode "0.3.2")
@@ -10,8 +10,8 @@
     (flycheck     "32")
     (async        "1.9.7"))
   :url "https://github.com/gmlarumbe/vhdl-ext"
-  :commit "5a3513d2f26ace017e9fab7141754ff5bdebb0eb"
-  :revdesc "5a3513d2f26a"
+  :commit "abaeede75309794b6d104af2d387452f148e5ca4"
+  :revdesc "abaeede75309"
   :keywords '("vhdl" "ide" "tools")
   :authors '(("Gonzalo Larumbe" . "gonzalomlarumbe@gmail.com"))
   :maintainers '(("Gonzalo Larumbe" . "gonzalomlarumbe@gmail.com")))
